@@ -7,8 +7,3 @@ from djpb.proto_to_django import (
 )
 from djpb.registry import register_model
 from .custom_field import CustomField, ReadOnlyField
-
-try:
-    from djpb.rest_framework_serializer import RestFrameworkSerializer
-except ImportError:
-    pass
